@@ -158,7 +158,6 @@ def prepare_memtier_benchmark_parameters(
     tls_cert=None,
     tls_key=None,
     tls_cacert=None,
-    password=None,
 ):
     benchmark_command = [
         full_benchmark_path,
@@ -169,8 +168,6 @@ def prepare_memtier_benchmark_parameters(
         "--json-out-file",
         local_benchmark_output_filename,
     ]
-    if password is not None:
-        benchmark_command.extend(["-a", password])
     if tls_enabled:
         benchmark_command.append("--tls")
         if tls_cert is not None and tls_cert != "":
@@ -246,7 +243,6 @@ def process_self_contained_coordinator_stream(
 
                     port = args.db_server_port
                     host = args.db_server_host
-                    password = args.db_server_pass
 
                     ssl_cert_reqs = "required"
                     if tls_skip_verify:
@@ -254,7 +250,6 @@ def process_self_contained_coordinator_stream(
                     r = redis.StrictRedis(
                         host=host,
                         port=port,
-                        password=password,
                         ssl=tls_enabled,
                         ssl_cert_reqs=ssl_cert_reqs,
                         ssl_keyfile=tls_key,
@@ -309,7 +304,6 @@ def process_self_contained_coordinator_stream(
                             test_tls_cert,
                             test_tls_key,
                             test_tls_cacert,
-                            password,
                         )
 
                     execute_init_commands(
@@ -370,7 +364,6 @@ def process_self_contained_coordinator_stream(
                             test_tls_cert,
                             test_tls_key,
                             test_tls_cacert,
-                            password,
                         )
 
                     client_container_image = extract_client_container_image(
@@ -642,7 +635,6 @@ def data_prepopulation_step(
     tls_cert=None,
     tls_key=None,
     tls_cacert=None,
-    password=None,
 ):
     # setup the benchmark
     (
@@ -675,7 +667,6 @@ def data_prepopulation_step(
             tls_cert,
             tls_key,
             tls_cacert,
-            password,
         )
 
         logging.info(
@@ -707,7 +698,7 @@ def data_prepopulation_step(
 
         preload_end_time = datetime.datetime.now()
         preload_duration_seconds = calculate_client_tool_duration_and_check(
-            preload_end_time, preload_start_time
+            preload_end_time, preload_start_time, "Preload", False
         )
         logging.info(
             "Tool {} seconds to load data. Output {}".format(
