@@ -183,7 +183,7 @@ def main():
     grafana_profile_dashboard = args.grafana_profile_dashboard
 
     # Consumer id
-    consumer_pos = args.consumer_id
+    consumer_pos = args.consumer_pos
     logging.info("Consumer pos {}".format(consumer_pos))
 
     profilers_list = []
@@ -632,7 +632,7 @@ def process_self_contained_coordinator_stream(
                                         "mode": "rw",
                                     },
                                 },
-                                auto_remove=False,
+                                auto_remove=True,
                                 privileged=True,
                                 working_dir=benchmark_tool_workdir,
                                 command=benchmark_command_str,
@@ -902,7 +902,7 @@ def data_prepopulation_step(
 
         preload_end_time = datetime.datetime.now()
         preload_duration_seconds = calculate_client_tool_duration_and_check(
-            preload_end_time, preload_start_time
+            preload_end_time, preload_start_time, "Preload", False
         )
         logging.info(
             "Tool {} seconds to load data. Output {}".format(
